<?php

global $newproject_text;
$newproject_text = array (

'createnewproject'	=>	'Ein neues Projekt erstellen',
'projecttitle'		=>	'Projekt Titel',
'themestyle'		=>	'Design',
'projectprefs'		=>	'Projekt-Einstellungen',
'defaultproject'	=>	'Standard Projekt',
'projectlists'		=>	'Projekt-Listen',
'addnewproject'		=>	'Neues Projekt hinzufügen',
'showlogo'			=>	'Logografik im Titel anzeigen',
'intromessage'		=>	'Begrüßungstext',
'htmlallowed'		=>	'HTML-Code zulassen',
'createproject'		=>	'Neues Projekt erstellen',
'noone'				=>	'Niemand',
'defaultcatowner'	=>	'Standard Kategorie-Inhaber',
'createthisproject'	=>	'Projekt erstellen',
'nopermission'		=>	'Sie sind nicht berechtigt, diese Seite zu verwenden.',

// Added in version 0.9.6
'inlineimages'		=>	'Angehängte Bilder als Vorschau anzeigen',

// Added in version 0.9.7
'othersview'        =>  'Jeder darf die Aufgaben dieses Projektes anzeigen',
'allowanonopentask' =>  'Jeder darf neue Aufgaben zu diesem Projekt hinzufügen',

);
?>
